
// BlastSprite.java
// Andrew Davison, May 2006, ad@fivedots.coe.psu.ac.th

/* A blast sprite is an animated sprite which starts at the
   current head position of the wand, and moves in the wand's 
   current direction. The sprite starts moving when 
   startMoving() is called from the BlastsManager object.

   When the sprite goes off screen, it becomes inactive, 
   and so can be reused by the BlastsManager in the future.

   The Sprite superclass is described in KGPJ chapter 11.
*/


public class BlastSprite extends Sprite
{
  private static final double DURATION = 1.0;  // secs
    // total time to cycle through all the images

  private int period;
   /* in ms. The game's animation period used by the image cycling. */


  public BlastSprite(int width, int height, ImagesLoader imsLd, int p) 
  { 
    super(0, 0, width, height, imsLd, "blast"); 
    period = p;
    setStep(0,0);  // no movement
    setActive(false);
  } // end of BlastSprite()


  public void startMoving(int xHead, int yHead, int xStep, int yStep)
  /* Start the blast moving at the wand head position
     (xHead, yHead) on the screen, with the step
     values (xStep, yStep).
  */
  { 
    // center the sprite at the wand head position
    setPosition(xHead - (getWidth()/2), yHead - (getHeight()/2) );
    setStep(xStep, yStep);   // movement direction
    loopImage(period, DURATION);   // cycle through the images
    setActive(true);
  } // end of moveLeft()


  public void updateSprite() 
  // the blast sprite become inactive after going off-screen
  {
    if (isActive()) {
      if ( ((locx+getWidth() < 0) && (dx < 0)) ||     // gone off lhs
           ((locx > getPWidth()) && (dx > 0)) ||      // gone off rhs
           ((locy+getHeight() < 0) && (dy < 0)) ||    // gone off top
           ((locy > getPHeight()) && (dy > 0)) ) {    // gone off bottom
        setStep(0,0);  // no movement
        setActive(false);
      }
      super.updateSprite();
    }
  } // end of updateSprite()

}  // end of BlastSprite class
