
// Blob.java
// Andrew Davison, May 2006, ad@fivedots.coe.psu.ac.th

/* A blob is a collecion of (x,y) points with the same
   (or similar) colour, which are all close to each other. 
*/

import java.awt.*;
import java.util.*;


public class Blob
{
  private static final int PROXIMITY = 4;
  /* Used to judge if a new point is close enough to the blob to
     join it. */

  private ArrayList<Point> points;
  private int numPoints;
  private int xSum, ySum;   // sum of (x,y) coords of the points


  public Blob()
  {  points = new ArrayList<Point>();
     numPoints = 0;  
     xSum = 0; ySum = 0;
  } // end of Blob()


  public boolean isClose(int x, int y)
  // is (x,y) close to a point in the blob?
  {
    for(Point p: points) {
      if ((Math.abs(x - p.x) < PROXIMITY) &&
          (Math.abs(y - p.y) < PROXIMITY))
        return true;
    }
    return false;
  }  // end of isClose()


  public void addPoint(int x, int y)
  // add (x,y) to the blob's points
  {  
    points.add( new Point(x,y) ); 
    numPoints++;
    xSum += x; ySum += y;
  }  // end of addPoint()


  public int numPoints()
  {  return numPoints;  }


  public Point getCenter()
  /* Return the center point of the blob. This is
     not particularly accurate unless the blob is convex
     (which is will be in this application). */
  { 
    int xAvg = xSum / numPoints;
    int yAvg = ySum / numPoints;
    return new Point(xAvg, yAvg);
  }  // end of getCenter()

}  // end of Blob class