
// MagicWand.java
// Andrew Davison, May 2006, ad@fivedots.coe.psu.ac.th

/* When the user moves a 'magic wand' in front of a webcam, 
   magic 'blasts' are emitted from a wand on screen. The 
   on-screen wand moves and rotates according to how the user's 
   wand moves and turns.

   This example combines the active rendering game framework
   from KGPJ chapters 2-4, sprites from chapter 11, and web
   snapping and analysis from the online chapter ??.

   -----
   Pausing/Resuming/Quiting are controlled via the frame's window
   listener methods.
*/


import javax.swing.*;
import java.awt.*;
import java.awt.event.*;


public class MagicWand extends JFrame implements WindowListener
{
  private static int DEFAULT_FPS = 40; 

  private MWPanel mwp;        // where the game is drawn


  public MagicWand(long period)
  { super("Magic Wand");

    Container c = getContentPane();    // default BorderLayout used
    mwp = new MWPanel(this, period);
    c.add(mwp, "Center");

    addWindowListener( this );
    pack();
    setResizable(false);
    setVisible(true);
  }  // end of MagicWand() constructor


  // ----------------- window listener methods -------------

  public void windowActivated(WindowEvent e) 
  { mwp.resumeGame();  }

  public void windowDeactivated(WindowEvent e) 
  { mwp.pauseGame();  }


  public void windowDeiconified(WindowEvent e) 
  {  mwp.resumeGame();  }

  public void windowIconified(WindowEvent e) 
  {  mwp.pauseGame(); }


  public void windowClosing(WindowEvent e)
  {  mwp.stopGame();  }

  public void windowClosed(WindowEvent e) {}
  public void windowOpened(WindowEvent e) {}

  // ----------------------------------------------------

  public static void main(String args[])
  { 
    long period = (long) 1000.0/DEFAULT_FPS;
    // System.out.println("fps: " + DEFAULT_FPS + "; period: " + period + " ms");
    new MagicWand(period*1000000L);    // ms --> nanosecs 
  }

} // end of MagicWand class


